@@ -1,5 +1,8 @@
 package Data::Format::Pretty::YAML;
 
+our $DATE = '2014-12-10'; # DATE
+our $VERSION = '0.08'; # VERSION
+
 use 5.010001;
 use strict;
 use warnings;
@@ -8,8 +11,6 @@ require Exporter;
 our @ISA = qw(Exporter);
 our @EXPORT_OK = qw(format_pretty);
 
-our $VERSION = '0.07'; # VERSION
-
 sub content_type { "text/yaml" }
 
 sub format_pretty {
@@ -32,8 +33,8 @@ sub format_pretty {
         local $YAML::Syck::SortKeys       = 1;
         local $YAML::Syck::Headless       = 1;
         if ($linum) {
-            require SHARYANTO::String::Util;
-            SHARYANTO::String::Util::linenum(YAML::Syck::Dump($data));
+            require String::LineNumber;
+            String::LineNumber::linenum(YAML::Syck::Dump($data));
         } else {
             YAML::Syck::Dump($data);
         }
@@ -55,7 +56,7 @@ Data::Format::Pretty::YAML - Pretty-print data structure as YAML
 
 =head1 VERSION
 
-version 0.07
+This document describes version 0.08 of Data::Format::Pretty::YAML (from Perl distribution Data-Format-Pretty-YAML), released on 2014-12-10.
 
 =head1 SYNOPSIS
 
@@ -134,7 +135,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Data-Forma
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Data-Format-Pretty-YAML>.
+Source repository is at L<https://github.com/perlancar/perl-Data-Format-Pretty-YAML>.
 
 =head1 BUGS
 
@@ -146,11 +147,11 @@ feature.
 
 =head1 AUTHOR
 
-Steven Haryanto <stevenharyanto@gmail.com>
+perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Steven Haryanto.
+This software is copyright (c) 2014 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
